==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ar/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'هذا المستخدم تسجيل الدخول',
    'activated_disabled_help_text' => 'لا يمكنك تعديل حالة التنشيط لحسابك الخاص.',
    'assets_user'       => 'الأصول التي تم اخراجها إلى :name',
    'bulk_update_warn'	=> 'أنت على وشك تعديل خصائص :user_count من المستخدمين. يرجى ملاحظة أنه لا يمكنك تغيير سمات المستخدم الخاصة بك باستخدام هذا النموذج، ويجب إجراء تعديلات على المستخدم الخاص بك بشكل على حدة.',
    'bulk_update_help'	=> 'يتيح لك هذا النموذج تحديث عدة مستخدمين في وقت واحد. قم بملء الحقول التي تحتاج إلى تغييرها. ستظل أية حقول فارغة فارغة دون تغيير.',
    'current_assets'    => 'يتم حاليا سحب الأصول إلى هذا المستخدم',
    'clone'             => 'نسخ المستخدم',
    'contact_user'      => 'الاتصال: :name',
    'edit'              => 'تعديل المستخدم',
    'filetype_info'     => 'انواع صيغ الملفات المسوح بها هي png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'الأرشيف الخاص بـ :name',
	'info'				=> 'معلومات',
    'restore_user'		=> 'انقر هنا لاستعادتها.',
    'last_login'        => 'آخر دخول للمستخدم',
    'ldap_config_text'  => 'يمكن العثور على إعدادات تهيئة لداب المشرف> الإعدادات. سيتم تعيين الموقع (اختياري) المحدد لجميع المستخدمين الذين تم استيرادهم.',
    'print_assigned'    => 'طباعة كل الممتلكات',
    'software_user'     => 'البرامج المخرجة الى: :name',
    'send_email_help'   => 'يجب عليك توفير عنوان بريد إلكتروني لهذا المستخدم لإرسال بيانات اعتماده. لا يمكن إرسال بيانات الاعتماد البريدية إلا عند إنشاء المستخدم. يتم تخزين كلمات المرور في تجزئة ذات اتجاه واحد ولا يمكن استرجاعها بمجرد الحفظ.',
    'view_user'         => 'عرض المستخدم :name',
    'usercsv'           => 'ملف CSV',
    'two_factor_admin_optin_help' => 'تسمح إعدادات المشرف الحالية بإنفاذ انتقائي للمصادقة الثنائية.',
    'two_factor_enrolled' => '2FA الجهاز المسجلين',
    'two_factor_active'   => '2FA نشط',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ar/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'هذا المستخدم تسجيل الدخول',
    'activated_disabled_help_text' => 'لا يمكنك تعديل حالة التنشيط لحسابك الخاص.',
    'assets_user'       => 'الأصول التي تم اخراجها إلى :name',
    'bulk_update_warn'	=> 'أنت على وشك تعديل خصائص :user_count من المستخدمين. يرجى ملاحظة أنه لا يمكنك تغيير سمات المستخدم الخاصة بك باستخدام هذا النموذج، ويجب إجراء تعديلات على المستخدم الخاص بك بشكل على حدة.',
    'bulk_update_help'	=> 'يتيح لك هذا النموذج تحديث عدة مستخدمين في وقت واحد. قم بملء الحقول التي تحتاج إلى تغييرها. ستظل أية حقول فارغة فارغة دون تغيير.',
    'current_assets'    => 'يتم حاليا سحب الأصول إلى هذا المستخدم',
    'clone'             => 'نسخ المستخدم',
    'contact_user'      => 'الاتصال: :name',
    'edit'              => 'تعديل المستخدم',
    'filetype_info'     => 'انواع صيغ الملفات المسوح بها هي png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'الأرشيف الخاص بـ :name',
    'info'				=> 'معلومات',
    'restore_user'		=> 'انقر هنا لاستعادتها.',
    'last_login'        => 'آخر دخول للمستخدم',
    'ldap_config_text'  => 'يمكن العثور على إعدادات تهيئة لداب المشرف> الإعدادات. سيتم تعيين الموقع (اختياري) المحدد لجميع المستخدمين الذين تم استيرادهم.',
    'print_assigned'    => 'طباعة كل الممتلكات',
    'software_user'     => 'البرامج المخرجة الى: :name',
    'send_email_help'   => 'يجب عليك توفير عنوان بريد إلكتروني لهذا المستخدم لإرسال بيانات اعتماده. لا يمكن إرسال بيانات الاعتماد البريدية إلا عند إنشاء المستخدم. يتم تخزين كلمات المرور في تجزئة ذات اتجاه واحد ولا يمكن استرجاعها بمجرد الحفظ.',
    'view_user'         => 'عرض المستخدم :name',
    'usercsv'           => 'ملف CSV',
    'two_factor_admin_optin_help' => 'تسمح إعدادات المشرف الحالية بإنفاذ انتقائي للمصادقة الثنائية.',
    'two_factor_enrolled' => '2FA الجهاز المسجلين',
    'two_factor_active'   => '2FA نشط',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'تحذير:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
